# PryvX-ML

## Overview

PryvX-ML is a Federated Learning library for training ML models on client side and aggregating model parameters at the server side.
Ecah client connects to the pryvx-ml federated server with unique project ID, collaborater ID and access key.